/* -*- pftp-c -*- */

#ifndef SETHOSTS_H
#define SETHOSTS_H

#include <pftp_settings.h>

int sethost(const char *site, int save_pass, int clr_pass, 
	    pftp_settings_t conf);

#endif /* SETHOSTS_H */
